/* main.c
 * Copyright (C) 2002 DindinX <David@dindinx.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "tologo.h"
#include "pnm.h"
#include "convert.h"
#include "write_logo.h"

void
version(void)
{
	printf("tologo version 1.0.1 \n");
}

void
usage(void)
{
	printf("tologo \n");
	printf("    A command line utility to create linux_logo.h files.\n\n");
	printf("    It does color space reduction and dithering as required.\n");
	printf("Usage: \n");
	printf("    tologo [--version] [--help] logo_filename.ppm header_filename.h \n\n");
	printf("    \"logo_filename.ppm\" is the pathname of the input graphics file.\n");
	printf("        The input file must be in the ppm format.\n");
	printf("        See \"man 5 ppm\" for information on ppm.\n");
	printf("        The Gimp and other programs can save as ppm.\n");
	printf("        If saving from the Gimp, use the \"Raw\" option for ppm.\n\n");
	printf("    \"header_filename.h\" is the pathname of the output header file.\n");
	printf("        Any existing file at that location will be overwritten.\n\n");
	printf("Options: \n");
	printf("    --version    show version and exit.\n");
	printf("    --help       display this help and exit.\n\n");
	printf("Copyright: \n");
	printf("    tologo is copyright David Odin, and others.\n");
	printf("    It is released under the GPL.\n\n");
	exit(0);
}

int
main(int argc, char *argv[])
{
	int i;
	char *in_file = NULL;
	char *out_file = NULL;
	LogoStruct *logo;

	for (i = 1; i < argc; i++) {
		if (!strcmp(argv[i], "--version")) {
			version();
			exit(0);
		} else if (!strcmp(argv[i], "--help")) {
			usage();
		} else {
			if (!in_file) {
				in_file = argv[i];
			} else if (!out_file) {
				out_file = argv[i];
			} else
				usage();
		}
	}

	if (!out_file)
		usage();

	printf("converting %s -> %s\n", in_file, out_file);

	logo = load_image(in_file);
	if (logo) {
		ConvertLogo(logo, 224);
		write_logo(logo, out_file);
	} else
	{
		printf("loading %s failed.\n", in_file);
		exit(-1);
	}

	return 0;
}
