/* write_logo.c
 * Copyright (C) 2002 DindinX <David@dindinx.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <stdlib.h>

#include "tologo.h"
#include "write_logo.h"

#define MIN(a, b)  (((a) < (b)) ? (a) : (b))

void
write_logo(LogoStruct * logo, char *out_file)
{
	FILE *file;
	int i, j;

	file = fopen(out_file, "w");
	if (file) {
		fprintf(file, "/*\n"
			" * include/linux/linux_logo.h: This is a linux logo\n"
			" *                             to be displayed on boot.\n"
			" *\n"
			" *  This file has been generated. Do not edit.\n"
			" */\n"
			"\n"
			"#ifndef __HAVE_ARCH_LINUX_LOGO\n"
			"#define LINUX_LOGO_COLORS       %d\n"
			"#endif\n"
			"\n"
			"#ifdef INCLUDE_LINUX_LOGO_DATA\n"
			"\n"
			"#ifndef __HAVE_ARCH_LINUX_LOGO\n"
			"\n"
			"#define LOGO_W  (%d)\n"
			"#define LOGO_H  (%d)\n"
			"\n"
			"unsigned char linux_logo_red[] __initdata = {\n",
			logo->NbCols, logo->width, logo->height);
		for (i = 0; i < 256; i += 8) {
			fprintf(file, "   ");
			for (j = 0; j < 8; j++) {
				fprintf(file, " 0x%02x", logo->Cmap_red[i + j]);
				if (i + j != 255)
					fprintf(file, ",");
			}
			fprintf(file, "\n");
		}
		fprintf(file,
			"};\n\nunsigned char linux_logo_green[] __initdata = {\n");
		for (i = 0; i < 256; i += 8) {
			fprintf(file, "   ");
			for (j = 0; j < 8; j++) {
				fprintf(file, " 0x%02x",
					logo->Cmap_green[i + j]);
				if (i + j != 255)
					fprintf(file, ",");
			}
			fprintf(file, "\n");
		}
		fprintf(file,
			"};\n\nunsigned char linux_logo_blue[] __initdata = {\n");
		for (i = 0; i < 256; i += 8) {
			fprintf(file, "   ");
			for (j = 0; j < 8; j++) {
				fprintf(file, " 0x%02x",
					logo->Cmap_blue[i + j]);
				if (i + j != 255)
					fprintf(file, ",");
			}
			fprintf(file, "\n");
		}
		fprintf(file,
			"};\n\nunsigned char linux_logo[] __initdata = {\n");
		for (i = 0; i < logo->width * logo->height; i += 8) {
			fprintf(file, "   ");
			for (j = 0; j < MIN(8, logo->width * logo->height - i);
			     j++) {
				fprintf(file, " 0x%02x",
					32 + logo->image[i + j]);
				if (i + j != logo->width * logo->height - 1)
					fprintf(file, ",");
			}
			fprintf(file, "\n");
		}
		fprintf(file, "};\n\n"
			"#endif /* !__HAVE_ARCH_LINUX_LOGO */\n"
			"\n"
			"#ifndef __HAVE_ARCH_LINUX_LOGOBW\n"
			"\n"
			"unsigned char linux_logo_bw[] __initdata = {\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xf0, 0x0f, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xcf, 0xf3, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xbf, 0xfc, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfd, 0xff, 0xf3, 0xdf, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x9f, 0x87, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x0f, 0x03, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x67, 0x33, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xe7, 0x79, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xf7, 0x79, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xff, 0xf9, 0xf7, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x60, 0x3b, 0xf7, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x89, 0x07, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x00, 0x03, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x00, 0x0d, 0xfb, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x80, 0x33, 0xfd, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xc0, 0xc3, 0xfd, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0xff, 0x0d, 0xdd, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xfb, 0x40, 0x31, 0xee, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf7, 0x20, 0xc1, 0xee, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf7, 0x1f, 0x00, 0xff, 0x7f, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xef, 0x00, 0x00, 0x7f, 0xbf, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xee, 0x00, 0x00, 0x7f, 0xbf, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xde, 0x00, 0x00, 0x7f, 0xdf, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xbc, 0x00, 0x00, 0x3f, 0xef, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0x7c, 0x00, 0x00, 0x3f, 0xf7, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0x7c, 0x00, 0x00, 0x1f, 0xf7, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xfe, 0xff, 0x1c, 0x07, 0xdf, 0xfb, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xfd, 0xfc, 0x08, 0x0f, 0xef, 0xfd, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xfd, 0xf8, 0x00, 0x01, 0xef, 0xfd, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xfb, 0xf0, 0x00, 0x00, 0x7f, 0xfe, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xfb, 0xe0, 0x00, 0x00, 0x1f, 0xfe, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xf7, 0xe0, 0x00, 0x00, 0x07, 0xbf, 0x7f, 0xff,\n"
			"    0xff, 0xff, 0xf7, 0xc0, 0x00, 0x00, 0x03, 0xbf, 0x7f, 0xff,\n"
			"    0xff, 0xff, 0xef, 0xc0, 0x00, 0x00, 0x03, 0xdf, 0xbf, 0xff,\n"
			"    0xff, 0xff, 0xef, 0x80, 0x00, 0x00, 0x03, 0xdf, 0xbf, 0xff,\n"
			"    0xff, 0xff, 0xdf, 0x80, 0x00, 0x00, 0x03, 0xdf, 0xbf, 0xff,\n"
			"    0xff, 0xff, 0xdf, 0x80, 0x00, 0x00, 0x01, 0xef, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xdf, 0x80, 0x00, 0x00, 0x01, 0xef, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xbf, 0x00, 0x20, 0x00, 0x01, 0xef, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xbf, 0x00, 0x20, 0x00, 0x01, 0xef, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xbf, 0x00, 0x20, 0x00, 0x01, 0xef, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xbf, 0x00, 0x20, 0x00, 0x01, 0xef, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xbf, 0x00, 0x20, 0x00, 0x03, 0x03, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xbf, 0x00, 0x20, 0x00, 0x02, 0xfd, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xa3, 0x80, 0x00, 0x00, 0x1f, 0xff, 0xdf, 0xff,\n"
			"    0xff, 0xff, 0xc1, 0xc0, 0x00, 0x00, 0x11, 0xff, 0x3f, 0xff,\n"
			"    0xff, 0xff, 0x80, 0xe0, 0x00, 0x00, 0x21, 0xfe, 0x3f, 0xff,\n"
			"    0xff, 0xff, 0x00, 0x70, 0x00, 0x00, 0x21, 0xfc, 0x3f, 0xff,\n"
			"    0xff, 0xfe, 0x00, 0x3c, 0x00, 0x00, 0x20, 0xf8, 0x3f, 0xff,\n"
			"    0xff, 0xf0, 0x00, 0x3e, 0x00, 0x00, 0x20, 0x00, 0x3f, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x1f, 0x00, 0x00, 0x20, 0x00, 0x3f, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x1f, 0x80, 0x00, 0x20, 0x00, 0x1f, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x0f, 0x80, 0x00, 0x20, 0x00, 0x07, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x07, 0x80, 0x00, 0x20, 0x00, 0x03, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x07, 0x80, 0x00, 0x60, 0x00, 0x01, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x02, 0x00, 0x00, 0xe0, 0x00, 0x01, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x01, 0x00, 0x01, 0xe0, 0x00, 0x01, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x00, 0x80, 0x07, 0xe0, 0x00, 0x03, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x00, 0x80, 0x3f, 0xe0, 0x00, 0x0f, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x00, 0x7f, 0xff, 0xc0, 0x00, 0x1f, 0xff,\n"
			"    0xff, 0xc0, 0x00, 0x00, 0x7f, 0xff, 0xc0, 0x00, 0x7f, 0xff,\n"
			"    0xff, 0xe0, 0x00, 0x00, 0x7f, 0xff, 0xc0, 0x00, 0xff, 0xff,\n"
			"    0xff, 0xfc, 0x00, 0x00, 0x7f, 0xff, 0xc0, 0x03, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xc0, 0x00, 0x70, 0x00, 0xc0, 0x07, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xfc, 0x00, 0x8f, 0xff, 0x20, 0x0f, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0x01, 0xff, 0xff, 0xe0, 0x1f, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"};\n"
			"\n"
			"#endif /* !__HAVE_ARCH_LINUX_LOGOBW */\n"
			"\n"
			"#ifndef __HAVE_ARCH_LINUX_LOGO16\n"
			"\n"
			"unsigned char linux_logo16[] __initdata = {\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x88, 0x88, 0x88, 0x80, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x88, 0x80, 0x00, 0x00, 0x08, 0x88, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x88,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x87, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x77, 0x80,\n"
			"    0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x08, 0x70, 0x00, 0x00, 0x00, 0x77, 0x70, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x87, 0x77, 0x00, 0x00, 0x07, 0xff, 0xf7, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,\n"
			"    0x77, 0xff, 0x00, 0x00, 0x7f, 0x77, 0xf7, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,\n"
			"    0x70, 0x0f, 0x80, 0x00, 0xf7, 0x08, 0x7f, 0x70,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,\n"
			"    0x80, 0x07, 0x80, 0x00, 0xf8, 0x00, 0x8f, 0x70,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08,\n"
			"    0x70, 0x07, 0x88, 0x88, 0xf8, 0x00, 0x8f, 0x70,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0xf0, 0x06, 0xe6, 0xe6, 0xe6, 0x00, 0x8f, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x77, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x77, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x06, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x60,\n"
			"    0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x60,\n"
			"    0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x66, 0x66, 0x80,\n"
			"    0x08, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,\n"
			"    0x86, 0xe6, 0xe6, 0xe6, 0x66, 0x66, 0x66, 0x80,\n"
			"    0x08, 0x78, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,\n"
			"    0x86, 0x66, 0x66, 0x66, 0x66, 0x66, 0x77, 0x70,\n"
			"    0x00, 0x77, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x87, 0x66, 0x66, 0x66, 0x66, 0x77, 0x77, 0x78,\n"
			"    0x00, 0x88, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x87, 0x76, 0x66, 0x66, 0x77, 0x77, 0xff, 0xf7,\n"
			"    0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x08,\n"
			"    0xff, 0x77, 0x77, 0x77, 0x77, 0xff, 0xff, 0xff,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07,\n"
			"    0xff, 0x77, 0x77, 0x77, 0x7f, 0xff, 0xff, 0xff,\n"
			"    0x70, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x8f,\n"
			"    0xff, 0xf7, 0x77, 0x77, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf0, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x08, 0x7f,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf8, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf7, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x08, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x87, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x80, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x87, 0x77,\n"
			"    0xff, 0xf7, 0x77, 0xff, 0xff, 0xff, 0x77, 0x77,\n"
			"    0x77, 0x78, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x77, 0x7f,\n"
			"    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x77,\n"
			"    0x77, 0x78, 0x00, 0x80, 0x00, 0x00, 0x00, 0x80,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x7f, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf7, 0x77, 0x00, 0x08, 0x80, 0x00, 0x00, 0x80,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x80, 0x80, 0x08, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x77, 0x80, 0x00, 0x08, 0x00, 0x00, 0x08,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x08, 0x00, 0x80, 0x07, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0x78, 0x00, 0x08, 0x80, 0x00, 0x08,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x08, 0x08, 0x00, 0x8f, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xf7, 0x08, 0x80, 0x80, 0x00, 0x08,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x08, 0x08, 0x08, 0x7f, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xf7, 0x08, 0x80, 0x80, 0x00, 0x00,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x08, 0x07, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0x80, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x80, 0x80, 0x0f, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0x70, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x08, 0x00, 0x80, 0x8f, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0x70, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x08, 0x08, 0x00, 0x7f, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0x70, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x80, 0x08, 0x00, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x08, 0x00, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x08, 0x08, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x08, 0x08, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x88, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf0, 0x00, 0x08, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x08, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf0, 0x88, 0x88, 0x80, 0x00,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x08, 0x06, 0xe6, 0x00, 0x8f, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xf8, 0x00, 0x00, 0x08, 0x80,\n"
			"    0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x6e, 0x6e, 0x60, 0x08, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x88,\n"
			"    0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x06, 0xe6, 0xe6, 0xe6, 0x00, 0x8f, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xfe, 0x6e, 0x60, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x60, 0x08, 0xff, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xf6, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x06,\n"
			"    0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x8f, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0xfe, 0x6e, 0x60, 0x00, 0x00, 0x00, 0x0e,\n"
			"    0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x08, 0xff,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xff, 0x76, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0xe6,\n"
			"    0xe6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x8f,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf7, 0x7e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x60, 0x00, 0x08,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf7, 0x76, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00,\n"
			"    0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf7, 0x7e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x60, 0x00,\n"
			"    0x0f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf7, 0x76, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe0, 0x00,\n"
			"    0x8f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0xf7, 0x8e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x88,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,\n"
			"    0x78, 0x86, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xef,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7,\n"
			"    0x80, 0x06, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,\n"
			"    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x78,\n"
			"    0x00, 0x06, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x78, 0x80,\n"
			"    0x00, 0x06, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x0e, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x66,\n"
			"    0x67, 0xff, 0xff, 0xff, 0xff, 0x78, 0x80, 0x00,\n"
			"    0x00, 0x86, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe0, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x06, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x86, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e,\n"
			"    0x66, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x0e, 0x6e, 0x6e, 0x6e,\n"
			"    0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x66,\n"
			"    0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x86, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0xe6, 0xe6, 0xe6,\n"
			"    0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6, 0xe6,\n"
			"    0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x86, 0x6e, 0x6e, 0x6e, 0x6e, 0x66, 0x66,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66,\n"
			"    0x66, 0x66, 0x6e, 0x6e, 0x6e, 0x6e, 0x6e, 0x66,\n"
			"    0x60, 0x00, 0x88, 0x88, 0x88, 0x88, 0x88, 0x80,\n"
			"    0x00, 0x06, 0x66, 0xe6, 0xe6, 0xe6, 0x66, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x66, 0x66, 0x66, 0x66, 0xe6, 0xe6, 0x66,\n"
			"    0x88, 0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08,\n"
			"    0x88, 0x86, 0x66, 0x6e, 0x6e, 0x66, 0x60, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x06, 0x66, 0x66, 0x66, 0x66,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x06, 0x66, 0x66, 0x66, 0x66, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x06, 0x66, 0x66, 0x60,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x66, 0x66, 0x66, 0x60, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,\n"
			"};\n"
			"\n"
			"#endif /* !__HAVE_ARCH_LINUX_LOGO16 */\n"
			"\n"
			"#else /* !INCLUDE_LINUX_LOGO_DATA */\n"
			"\n"
			"/* prototypes only */\n"
			"extern unsigned char linux_logo_red[];\n"
			"extern unsigned char linux_logo_green[];\n"
			"extern unsigned char linux_logo_blue[];\n"
			"extern unsigned char linux_logo[];\n"
			"extern unsigned char linux_logo_bw[];\n"
			"extern unsigned char linux_logo16[];\n"
			"\n" "#endif /* !INCLUDE_LINUX_LOGO_DATA */\n");
		fclose(file);
	} else {
		printf("cannot open %s for writing.\n", out_file);
		exit(-1);
	}
}
